@@ -10,7 +10,7 @@ source "${BASH_SOURCE%/*}/DownloadURL.sh"
 
 version="3.1.37"
 versionNode="v14.18.2"
-tarBallVersion=$(sed "s/\./\_/g" <<<"$version")
+tarBallVersion="${version//./_}"
 if uname -a |grep -q Darwin; then
     tarBallPackage="emsdk_macos_${tarBallVersion}.tar.gz"
     sha="fe9900b0f27ada608f25552dbd4a58bf62c6f05b"
@@ -18,7 +18,7 @@ else
     tarBallPackage="emsdk_linux_${tarBallVersion}.tar.gz"
     sha="000bbd5666d8fc1afbf2dce1a7938ef0efeeab3f"
 fi
-cacheUrl="https://ci-files01-hki.intra.qt.io/input/emsdk/${tarBallPackage}"
+cacheUrl="https://ci-files01-hki.ci.qt.io/input/emsdk/${tarBallPackage}"
 target="/tmp/${tarBallPackage}"
 
 mkdir -p /opt
