@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# Copyright (C) 2023 The Qt Company Ltd.
+# Copyright (C) 2022 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 # This script will build and install FFmpeg static libs
@@ -11,9 +11,9 @@ source "${BASH_SOURCE%/*}/../unix/InstallFromCompressedFileFromURL.sh"
 # shellcheck source=../unix/SetEnvVar.sh
 source "${BASH_SOURCE%/*}/../unix/SetEnvVar.sh"
 
-version="n6.1"
-url_public="https://github.com/FFmpeg/FFmpeg/archive/$version.tar.gz"
-sha1="1feb946476f3076a9b38c97ca0d8b69e1826049c"
+version="n6.0"
+url_public="https://github.com/FFmpeg/FFmpeg/archive/refs/tags/$version.tar.gz"
+sha1="78435ec71cc2227017a99c030e858719b8c7c74d"
 url_cached="http://ci-files01-hki.ci.qt.io/input/ffmpeg/$version.tar.gz"
 ffmpeg_name="FFmpeg-$version"
 
@@ -21,7 +21,7 @@ target_dir="$HOME"
 app_prefix=""
 ffmpeg_source_dir="$target_dir/$ffmpeg_name"
 
-if [ ! -d "$ffmpeg_source_dir" ];
+if [ ! -d "$ffmpeg_source_dir" ]
 then
    InstallFromCompressedFileFromURL "$url_cached" "$url_public" "$sha1" "$target_dir" "$app_prefix"
 fi
@@ -35,7 +35,7 @@ install_ff_nvcodec_headers() {
   nv_codec_sha1="ceb4966ab01b2e41f02074675a8ac5b331bf603e"
   #nv_codec_sha1="4f30539f8dd31945da4c3da32e66022f9ca59c08" // 12.0
   nv_codec_dir="$target_dir/nv-codec-headers-sdk-$nv_codec_version"
-  if [ ! -d  "$nv_codec_dir" ];
+  if [ ! -d  "$nv_codec_dir" ]
   then
     InstallFromCompressedFileFromURL "$nv_codec_url_cached" "$nv_codec_url_public" "$nv_codec_sha1" "$target_dir" ""
   fi
@@ -62,11 +62,12 @@ build_ffmpeg() {
   then cc="clang -arch $arch"
   fi
 
+  # shellcheck disable=SC2086
   if [ -n "$arch" ]
-  then $ffmpeg_source_dir/configure $ffmpeg_config_options --prefix="$prefix" --enable-cross-compile --arch=$arch --cc="$cc"
-  else $ffmpeg_source_dir/configure $ffmpeg_config_options --prefix="$prefix"
+  then "$ffmpeg_source_dir/configure" $ffmpeg_config_options --prefix="$prefix" --enable-cross-compile --arch="$arch" --cc="$cc"
+  else "$ffmpeg_source_dir/configure" $ffmpeg_config_options --prefix="$prefix"
   fi
-  make install DESTDIR=$build_dir/installed -j4
+  make install DESTDIR="$build_dir/installed" -j4
   popd
 }
 
@@ -95,3 +96,4 @@ elif [ "$os" == "macos-universal" ]; then
   SetEnvVar "FFMPEG_DIR" "/usr/local/$ffmpeg_name"
 
 fi
+
